diff --git a/includes/statuses.preprocess.inc b/includes/statuses.preprocess.inc
index a0c13a6..53ebf7e 100644
--- a/includes/statuses.preprocess.inc
+++ b/includes/statuses.preprocess.inc
@@ -102,7 +102,7 @@ function _statuses_show($status, $options) {
     'extras' => TRUE,
   );
   if ($options['links']) {
-    $status->links = module_invoke_all('link', 'statuses', $status);
+    $status->links = module_invoke_all('statuses_link', 'statuses', $status);
     drupal_alter('statuses_link', $status->links, $status);
     uasort($status->links, '_statuses_links_sort');
   }
diff --git a/statuses.module b/statuses.module
index 159b5a6..1f0b0e7 100644
--- a/statuses.module
+++ b/statuses.module
@@ -385,9 +385,9 @@ function statuses_init() {
 }
 
 /**
- * Implements hook_link().
+ * Implements hook_statuses_link().
  */
-function statuses_link($type, $status) {
+function statuses_statuses_link($type, $status) {
   if ($type != 'statuses') {
     return;
   }

diff --git a/api.php b/api.php
index 0ba8038..1ee3c62 100644
--- a/api.php
+++ b/api.php
@@ -148,7 +148,7 @@ function hook_statuses_refresh_selectors($recipient, $type) {
 }
 
 /**
  * hook_link() is invoked with parameters 'statuses' and $status.
  * Implement it just like you would implement hook_link() with nodes in D6.
  *
  * @param $type
@@ -158,21 +158,19 @@ function hook_statuses_refresh_selectors($recipient, $type) {
  * @return
  *   A structured array which will be run through drupal_render() to produce
  *   links that will be displayed with themed statuses.
- * @see statuses_link()
+ * @see statuses_statuses_link()
  * @see _statuses_show()
  */
-if (!function_exists('hook_link')) {
-  function hook_link($type, $object, $teaser = FALSE) {
-    $links = array();
-    if ($type == 'statuses') {
-      $status = $object;
-      $links['permalink'] = array(
-        'href' => 'statuses/'. $status->sid,
-        'title' => t('Permalink'),
-      );
-    }
-    return $links;
+function hook_statuses_link($type, $object, $teaser = FALSE) {
+  $links = array();
+  if ($type == 'statuses') {
+    $status = $object;
+    $links['permalink'] = array(
+      'href' => 'statuses/'. $status->sid,
+      'title' => t('Permalink'),
+    );
   }
+  return $links;
 }
 
 /**
@@ -148,7 +148,7 @@ function hook_statuses_refresh_selectors($recipient, $type) {
 
 /**
- * hook_link() is invoked with parameters 'statuses' and $status.
+ * hook_statuses_link() is invoked with parameters 'statuses' and $status.
  * Implement it just like you would implement hook_link() with nodes in D6.
  *